@@ -1,20 +1,21 @@
 mod action;
-mod args;
+mod auto_refresh;
 mod cargo_wrapped_config;
 mod config;
 mod defaults;
 mod keybindings;
-
 mod settings;
+mod skin;
 
 pub use {
     action::*,
-    args::*,
+    auto_refresh::*,
     cargo_wrapped_config::*,
     config::*,
     defaults::*,
     keybindings::*,
     settings::*,
+    skin::*,
 };
 
 use std::path::{
